package com.sxtvs.open.api.user.service.impl;

import cn.hutool.crypto.SecureUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.sxtvs.open.api.user.dto.LoginDto;
import com.sxtvs.open.api.user.dto.TokenDto;
import com.sxtvs.open.api.user.entity.User;
import com.sxtvs.open.api.user.mapper.UserMapper;
import com.sxtvs.open.api.user.service.IUserService;
import com.sxtvs.open.core.advice.BizException;
import com.sxtvs.open.core.auth.AESUtil;
import com.sxtvs.open.core.sls.AliyunLogger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author zyx
 * @since 2023-02-15
 */
@Service
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements IUserService {

    @Autowired
    private AliyunLogger logger;

    public TokenDto login(LoginDto dto) {

        logger.info("key", "login", "dto", dto);

        var optionalUser = lambdaQuery().eq(User::getLoginName, dto.getLoginName())
                .eq(User::getLoginPassword, dto.getLoginPassword())
                .oneOpt();

        if (optionalUser.isEmpty()) {
            throw new BizException("用户不存在");
        }

        var id = optionalUser.get().getId();

        var token = AESUtil.encryptHex(id.toString());
        var tokenDto = new TokenDto();
        tokenDto.setToken(token);
        return tokenDto;

    }

    public void createUser(String userName, String pwd) {
        var user = new User();
        user.setLoginName(userName);
        user.setLoginPassword(SecureUtil.sha256(pwd));
        user.setEncodePassword(AESUtil.encryptHex(pwd));
        save(user);
    }
}
